# UTF-8 encoded Korean translation file for use with Oddmuse
#
# Copyright (c) 2006  Joonhwan Lee <joonhwan.lee@gmail.com>
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
$ModulesDescription .= '<p>$Id: korean-utf8.pl,v 1.5 2009/06/07 19:30:37 as Exp $</p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Include normal pages
정상 페이지를 포함하여
Reading not allowed: user, ip, or network is blocked.
읽기가 허락되지 않습니다: 사용자아이디, ip, 또는 네트웍이 접근거부되었습니다.
Login

Error

%s calls

Could not create %s
%s 를 생성할 수 없습니다.
Invalid UserName %s: not saved.
%s 는 존재하지 않는 사용자명입니다: 저장되지 않았습니다.
UserName must be 50 characters or less: not saved
사용자이름은 50자를 이내이어야 합니다: 저장되지 않았습니다.
This page contains an uploaded file:
이 페이지는 업로드된 파일을 포함하고 있습니다:
Recursive include of %s!
%s 가 재귀적으로 포함되었습니다!
Clear Cache
캐시 삭제
Main lock obtained.
메인 잠금 획득.
Main lock released.
메인 잠금 해제.
Journal

More...

Comments on this page
이 페이지에 커맨트하세요
XML::RSS is not available on this system.
이 시스템에서는 XML:RSS 를 사용할 수 없습니다.
diff
차이
history
변경사항
%s returned no data, or LWP::UserAgent is not available.
%s 에서 어무런 데이터를 받지 못했거나 LWP::UserAgent 가 없습니다.
RSS parsing failed for %s
%s 에 대한 RSS 파싱이 실패하였습니다.
No items found in %s.
%s 에서 아무런 항목도 찾지 못했습니다.
 . . . . 
 . . . . 
Click to edit this page
클릭하여 페이지를 편집합니다
CGI Internal error: %s
CGI 내부 오류 : %s
Invalid action parameter %s
유효하지 않은 액션 파라메터 %s
Page name is missing
페이지 이름이 없습니다
Page name is too long: %s
페이지 이름( %s )이 너무 깁니다.
Invalid Page %s (must not end with .db)
페이지 이름 %s 이 유효하지 않습니다( .db 로 끝나면 안됩니다 )
Invalid Page %s (must not end with .lck)
페이지 이름 %s 이 유효하지 않습니다( .lck 로 끝나면 안됩니다 )
Invalid Page %s
%s 은 유효하지 않은 페이지입니다.
Too many redirections

No redirection for old revisions

Invalid link pattern for #REDIRECT

Please go on to %s.
%s 로 이동하여 주세요.
Updates since %s
%s 이후의 업데이트
Updates in the last %s days
최근 %s 일 동안 업데이트
Updates in the last %s day
지난 %s 일의 업데이트
for %s only
%s 에만 해당
List latest change per page only
페이지별로만 최근 변경 보기
List all changes
모든 변경 보기
Skip rollbacks
롤백 건너뜀
Include rollbacks
롤백 포함
List only major changes
큰 변경사항만 나열
Include minor changes
작은 변경사항 포함
%s days
%s 일
List later changes
이후의 변경 나열
RSS

RSS with pages

RSS with pages and diff

Filters
필터
Title:
제목:
Title and Body:
제목과 내용:
Username:
사용자명:
Host:
호스트:
Follow up to:

Language:
언어:
Go!
이동!
(minor)
(minor)
rollback
롤백
new
새로운 사항
All changes for %s

from %s
%s 로 부터
This page is too big to send over RSS.
RSS 로 전송하기에 너무 큰 페이지 입니다.
History of %s
%s 에 대한 변경사항
Compare
비교
Deleted
삭제됨
Mark this page for deletion
이 페이지를 삭제할 페이지로 표시
No other revisions available
다른 리비젼이 없습니다.
current
현재
Revision %s
리비젼 %s
Contributors to %s
%s 제안자
Missing target for rollback.
롤백에 대한 대상이 없습니다.
Target for rollback is too far back.
롤백에 대한 대상이 너무 오래되었습니다.
A username is required for ordinary users.

Rolling back changes
변경사항을 롤백
The two revisions are the same.
이 두개의 리비젼은 동일합니다.
Editing not allowed for %s.
%s 에 대한 편집이 허용되지 않습니다.
Rollback to %s
%s 로 롤백
%s rolled back
%s 가 롤백됨
to %s
%s 로
Index of all pages
모든 페이지에 대한 인덱스
Wiki Version
위키 버젼
Unlock Wiki
위키 잠금 해제
Password
암호
Run maintenance
유지보수 실행
Unlock site
사이트 잠금
Lock site
사이트 잠금
Install CSS
CSS 설치
Unlock %s
%s 잠금해제
Lock %s
%s 잠금
Administration
관리
Actions:
동작:
Important pages:
중요한 페이지들:
To mark a page for deletion, put <strong>%s</strong> on the first line.
특정 페이지를 삭제 요청페이지로 하려면, <strong>%s</strong> 를 첫줄에 입력하세요. 
[Home]
[홈]
redirected from %s
%s 에서 재전송됨
%s: 

Click to search for references to this page
이 페이지에 대한 참조를 검색하려면 클릭
Cookie: 
쿠키:
Edit this page
이 페이지를 편집
Preview:
미리보기:
Preview only, not yet saved
미리보기만 가능합니다. 저장되지는 않습니다.
Warning
경고
Database is stored in temporary directory %s
데이터베이스가 임시 디렉토리 %s 에 저장되었습니다.
%s seconds
%s 초
Last edited
최근에 편집됨
Edited
편집됨
by %s
%s 에 의해
(diff)
(차이)
Edit revision %s of this page
이 페이지의 리비젼 %s 를 편집
e
e
This page is read-only
이 페이지는 읽기전용입니다.
View other revisions
다른 리비젼들 보기
View current revision
현재 리비젼 보기
View all changes
모든 변경사항 보기
View contributors
제안자들 보기
Homepage URL:
홈페이지 주소:
s
s
Save
저장
p
p
Preview
미리보기
Search:
검색:
f
f
Replace:
바꾸기:
Delete

Validate HTML
HTML 검증
Validate CSS
CSS 검증
Last edit
최근 편집
Difference between revision %1 and %2
리비젼 %1 과 %2 간의 차이
revision %s
리비젼 %s
current revision
현재 리비젼
Last major edit (%s)
마지막 주요 편집 (%s)
later minor edits
마지막 세부 편집들
No diff available.
차이를 찾지 못함.
Old revision:
오래된 리비젼:
Changed:
변경됨:
Deleted:
삭제됨:
Added:
추가됨:
to
(으)로
Revision %s not available
리비젼 %s 는 유효하지 않습니다
showing current revision instead
현재 리비젼을 대신 보여줍니다
Showing revision %s
%s 리비젼을 보여줍니다
Cannot save a nameless page.
이름없는 페이지는 저장할 수 없습니다.
Cannot save a page without revision.
리비젼 없는 페이지는 저장할 수 없습니다.
Cannot open %s
%s (을)를 열 수 없습니다.
Cannot write %s
%s (을)를 기록할 수 없습니다.
Cannot create %s
%s (을)를 생성할 수 없습니다.
Could not get %s lock
%s 의 잠금이 불가했습니다
The lock was created %s.
%s 잠궜습니다.
This operation may take several seconds...
이 작업은 시간이 약간 걸릴 수 있습니다...
Forced unlock of %s lock.
%s 의 잠금이 강제로 해제되었습니다.
No unlock required.
잠금해제할 필요가 없습니다.
%s hours ago
%s 시간 전
1 hour ago
1 시간 전
%s minutes ago
%s 분 전
1 minute ago
1 분 전
%s seconds ago
%s 초 전
1 second ago
1 초 전
just now
바로 지금
Edit Denied
편집 거부되었습니다.
Editing not allowed: user, ip, or network is blocked.
편집이 허용되지 않습니다: 사용자명, ip, 또는 네트워크가 충돌하였습니다.
Contact the wiki administrator for more information.
상세 정보를 위해서는 위키 관리자에게 연락하세요.
The rule %s matched for you.
%s 규칙이 맞았습니다.
See %s for more information.
상세정보는 %s 를 참조하세요.
Editing not allowed: %s is read-only.
편집이 허용되지 않습니다: %s 는 읽기전용입니다.
Only administrators can upload files.
오직 관리자만이 파일을 업로드할 수 있습니다.
Editing revision %s of
리비젼 %s를 편집 - 
Editing %s
%s 를 편집
Editing old revision %s.
이전의 %s 리비젼을 편집
Saving this page will replace the latest revision with this text.
이 페이지를 저장하면 본문의 최근 리비젼이 바뀝니다.
Summary:
요약:
This change is a minor edit.
이 변경사항은 세부 편집입니다.
Cancel

Replace this file with text
이 파일을 텍스트로 바꿈
Replace this text with a file
이 텍스트를 파일로 바꿈
File to upload: 
업로드할 파일:
Files of type %s are not allowed.
%s (이)란 파일 유형은 허용되지 않습니다.
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
쿠키가 활성화 되어 있다면, 암호가 쿠키에 저장됩니다. 쿠키는 다른 컴퓨터에서, 다른 계정으로 또는 다른 소프트웨어로 접속하게 되면 없어질 수 있습니다.
You are currently an administrator on this site.
사용자가 이 사이트에 관리자입니다.
You are currently an editor on this site.
사용자가 이 페이지의 편집인입니다.
You are a normal user on this site.
사용자가 이 사이트의 정상 사용자입니다.
Your password does not match any of the  administrator or editor passwords.
사용자의 암호가 관리자 또는 편집자의 암호와 일치하지 않습니다.
Password:
암호:
This site does not use admin or editor passwords.
이 사이트는 관리자 또는 편집자 암호를 사용하지 않습니다.
This operation is restricted to site editors only...
이 동작은 사이트 편집자만 할 수 있습니다...
This operation is restricted to administrators only...
이 동작은 관리자만 할 수 있습니다.
SampleUndefinedPage
SampleUndefinedPage
Sample_Undefined_Page
Sample_Undefined_Page
Rule "%1" matched "%2" on this page.
규칙 "%1" 은 "%2" 와 이 페이지에서 맞지 않습니다.
Reason: %s.

Reason unknown.

Filter:
필터:
(for %s)
(%s(을)를 위하여)
%s pages found.
%s 페이지를 찾음.
Replaced: %s
바뀜: %s
Search for: %s
찾음: %s
View changes for these pages
이 페이지들에서의 변경사항을 봄
last updated
마지막 갱신
by
에 의해
Transfer Error: %s
전송 오류: %s
Browser reports no file info.
브라우저가 아무런 파일 정보도 보고하지 않습니다.
Browser reports no file type.
브라우저가 아무런 파일 유형도 보고하지 않습니다.
The page contains banned text.
이 페이지는 배너 텍스트를 포함합니다.
No changes to be saved.
저장할 변경사항이 없습니다.
This page was changed by somebody else %s.
이 페이지는 %s 이외의 사용자에 의해 변경되었습니다.
The changes conflict.  Please check the page again.
이 페이지들이 충돌합니다. 페이지를 다시 확인하세요.
Please check whether you overwrote those changes.
이 변경사항들에 덮어쓰기 하지 않았는지 확인하세요.
Anonymous
익명
Cannot delete the index file %s.
%s 인덱스 파일을 삭제 할 수 없습니다.
Please check the directory permissions.
디렉토리 권한을 확인하세요.
Your changes were not saved.
사용자의 변경사항이 저장되지 않았습니다.
Could not get a lock to merge!
병합을 위한 잠금을 가져오지 못했습니다.
you
사용자
ancestor
부모사용자(ancestor)
other
다른 사용자
Run Maintenance
관리자 메뉴 실행
Maintenance not done.
(사이트)관리가 완료되지 않았습니다.
(Maintenance can only be done once every 12 hours.)
(매 12시간에 한번씩 사이트 관리가 수행될 수 있습니다.)
Remove the "maintain" file or wait.
"유지보수(maintain)" 파일을 제거하거나 기다리세요.
Expiring keep files and deleting pages marked for deletion

not deleted: 
삭제되지 않음:
deleted
삭제됨
Moving part of the %s log file.
%s 로그 파일의 일부를 옮김.
Could not open %s log file
%s 로그 파일을 열 수 없었습니다.
Error was
오류는 
Note: This error is normal if no changes have been made.
주의: 변경이 전혀 없었다면 이 오류는 정상적인 것입니다.
Moving %s log entries.
%s 로그 엔트리를 옭김.
Set or Remove global edit lock
전역 편집 잠금을 설정하거나 제거
Edit lock created.
편집 잠금이 생성되었습니다.
Edit lock removed.
편집 잠금이 제거되었습니다.
Set or Remove page edit lock
편집 잠금을 설정하거나 제거합니다
Lock for %s created.
%s 에 대한 잠금이 생성되었습니다.
Lock for %s removed.
%s 에 대한 잠금이 제거되었습니다.
Displaying Wiki Version
위키 버젼을 표시
Debugging Information

Inter links:
인터 링크:
Too many connections by %s
%s 에 의해 너무 많은 접속이 있었습니다.
Please do not fetch more than %1 pages in %2 seconds.
%s 초 이내에 %1 페이지 이상을 덧붙이지 마세요.
Check whether the web server can create the directory %s and whether it can create files in it.
웹서버가 디렉토리 %s 를 생성하고 그 안에 파일을 생성할 수 있는지 확인하여 주세요.
Copy one of the following stylesheets to %s:
다음의 스타일시트중 하나를 %s 에 복사합니다:
Deleting %s
%s 를 삭제하고 있습니다
Deleted %s
%s 를 삭제하였습니다
Renaming %1 to %2.
%1 을 %2 로 이름바꿈
The page %s does not exist
%s 페이지가 존재하지 않습니다.
The page %s already exists
%s 페이지가 이미 존재합니다
Cannot rename %1 to %2
%1 을 %2 로 이름변경할 수 없습니다.
Renamed to %s
%s 로 이름변경됨
Renamed from %s
%s 로 부터 이름변경됨
Renamed %1 to %2.
%1 을 %2 로 이름변경함.
Immediately delete %s
%s 를 즉시 삭제함
Rename %s to:
%s의 이름을 다음으로 바꿈:
Learn more...
상세내용 알아보기...
Complete Content
전체 내용
The main page is %s.
메인페이지는 %s 입니다.
Archive:

Rebuild BackLink database

Internal Page: 

Pages that link to this page

The search parameter is missing.

Pages link to %s

Cannot highlight the language %s.
%s 언어에 대해서 구문강조를 할 수 없습니다.
Recent Visitors

some action

was here

and read

Illegal year value: Use 0001-9999
옳바르지 않은 연도값: 0001-9999 사이의 수를 사용하세요
The match parameter is missing.
일치하는 파라메터가 없습니다.
Page Collection for %s
%s 에 대한 페이지 컬렉션
Previous
이전
Next
다음
Calendar %s
%s 칼렌더
Su
일
Mo
월
Tu
화
We
수
Th
목
Fr
금
Sa
토
January
1월
February
2월
March
3월
April
4월
May
5월
June
6월
July
7월
August
8월
September
9월
October
10월
November
11월
December
12월
set %s

unset %s

Clustermap
클러스터맵(clustermap)
Pages without a Cluster
클러스터 없는 페이지들
Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

List spammed pages

Despamming pages
페이지에서 스팸제거
Spammed pages

Cannot find revision %s.
리비젼 %s를 찾을 수 없습니다.
Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Recover Draft

No text to save

Draft saved

Draft recovered

No draft available to recover

Save Draft

Draft Cleanup

%1 was last modified %2 and was kept

%1 was last modified %2 and was deleted

Unable to delete draft %s

Add Comment

ordinary changes

Matching page names:

Could not find %1.html template in %2

Only Editors are allowed to see this hidden page.

Only Admins are allowed to see this hidden page.

Index

Languages:
언어:
Show!
보여주세요!
Define
정의
Full Link List
전체 링크 목록
List of locked pages

Pages tagged with %s

Template without parameters
파라메터 없는 템플릿
The template %s is either empty or does not exist.
템플릿 %s (이)가 비어있거나 존재하지 않습니다.
 -- defined on %s
 -- %s 에 정의됨
Local names defined on %1: %2
%1 에 정의된 로컬 이름 : %2
Locked Pages

Register for %s

Please choose a username of the form "FirstLast" using your real name.

The passwords do not match.

The password must be at least %s characters.

That email address is invalid.

The username %s has already been registered.

Your registration for %s has been submitted.

Please allow time for the webmaster to approve your request.

An email has been sent to "%s" with further instructions.

There was an error saving your registration.

An account was created for %s.

Login to %s

Username and/or password are incorrect.

Logged in as %s.

Logout of %s

Logout of %s?

Logged out of %s

You are now logged out.

Register a new account

Logout

Who am I?

Forgot your password?

Change your password

Approve pending registrations

Confirm Registration for %s

%s, your registration has been approved. You can now use your password to login and edit this wiki.

Confirmation failed.  Please email %s for help.

Who Am I?

You are logged in as %s.

You are not logged in.

Reset Password

The password for %s was reset.  It has been emailed to the address on file.

There was an error resetting the password for %s.

The username "%s" does not exist.

Reset Password for %s

Reset Password?

Change Password for %s

Change Password?

Your current password is incorrect.

Your password has been changed.

Approve Pending Registrations for %s

%s has been approved.

There was an error approving %s.

<ul>

<li>%1 - %2</li>

</ul>

There are no pending registrations.

Invalid Mail %s: not saved.

unsubscribe

subscribe

Email: 

%s appears to be an invalid mail address

Your mail subscriptions

All mail subscriptions

Subscriptions

Show

Subscriptions for %s:

Unsubscribe

There are no subscriptions for %s.

Change email address

Mail addresses are linked to unsubscription links.

Subscribe to %s.

Subscribe

Subscribed %s to the following pages:

The remaining pages do not exist.

Unsubscribed %s from the following pages:

You linked more than %s times to the same domain. It would seem that only a spammer would do this. Your edit is refused.

%s is not a legal name for a namespace

Namespaces

Getting page index file for %s.
%s 에 대한 페이지 인덱스 파일을 얻음.
Near links:
근접 링크:
Search sites on the %s as well
%s 에 대해서도 사이트를 검색
Fetching results from %s:
%s 로 부터의 결과를 가져옴:
Near pages:
근접 페이지:
Include near pages
근접 페이지 포함하여
EditNearLinks
근접링크편집
The same page on other sites:
다른 사이트에 존재하는 동일한 페이지:
 (create locally)

image
이미지
download
다운로드
Backlinks

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view

Self-ban by %s

You have banned your own IP.

OpenID Login

Your identity is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.

Your homepage is set to %s.

You have no homepage set.

Homepage:

Homepage is missing

OpenID error %s

Orphan List

Trail: 

None

Type

Permalink to "%s"

anchor first defined here: %s
책갈피가 여기서 처음 거부되었습니다: %s
the page %s also exists
%s 페이지는 이미 존재합니다.
There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.

Someone else is generating a pdf for %s.  Please wait a minute and then try again.

Download this page as PDF

Click to search for references to this permanent anchor
이 영구 책갈피에 대한 참조를 검색하려면 클릭
Include permanent anchors
영구 책갈피 포함하여
Portrait

Publish %s

No target wiki was specified in the config file.

The target wiki was misconfigured.

You did not answer correctly.

To save this page you must answer this question:

Please type the following two words:

Please answer this captcha:

Referrers

All Referrers

Tag

Rebuild index for searching

Tag Cloud

Search::FreeText is not available on this system.

Rebuilding index not done.

(Rebuilding the index can only be done once every 12 hours.)

New Pages for Indexed Search

List changes since %s

 ... 

Search term missing.

Result pages: 

(%s results)

Tags:

Tags: %s.

No tags

Page list for %s

Slideshow:%s

Index of all small pages

Static Copy

Back to %s

Copy to %1 succeeded: %2.

Copy to %1 failed: %2.

Feed for this tag

Rebuild tag index

list tags

tag cloud

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Too many instances.  Only %s allowed.

Please try again later. Perhaps somebody is running maintenance or doing a long search. Unfortunately the site has limited resources, and so we must ask you for a bit of patience.

Contents

Create a new page for today

Add Translation

Added translation: %1 (%2)

Translate %s

Thank you for writing a translation of %s.

Please indicate what language you will be using.

Language is missing

Suggested languages:

Please indicate a page name for the translation of %s.

More help may be available here: %s.

Translated page: 

This page is a translation of %s. 

The translation is up to date.

The translation is outdated.

The page does not exist.

http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate

http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search

Wanted Pages

%s pages

%s, referenced from:

Upload of %s file

Blog

Matching pages:

New

Edit %s.

Title: 

Tags: 

END_OF_TRANSLATION
